@@ -9,7 +9,7 @@ orbital.step_center <- function(x, all_vars, ...) {
   used_vars <- names(means) %in% all_vars
   means <- means[used_vars]
 
-  out <- glue::glue("{names(means)} - {means}")
+  out <- glue::glue("{names(means)} - {format_numeric(means)}")
   names(out) <- names(means)
   out
 }
