@@ -11,11 +11,11 @@ orbital.step_log <- function(x, all_vars, ...) {
 
   if (x$signed) {
     out <- glue::glue(
-      "dplyr::if_else(abs({columns}) < 1, 0, sign({columns}) * log(abs({columns}), base = {x$base}))"
+      "dplyr::if_else(abs({columns}) < 1, 0, sign({columns}) * log(abs({columns}), base = {format_numeric(x$base)}))"
     )
   } else {
     out <- glue::glue(
-      "log({columns} + {x$offset}, base = {x$base})"
+      "log({columns} + {format_numeric(x$offset)}, base = {format_numeric(x$base)})"
     )
   }
 
