@@ -1,19 +1,46 @@
+test_that("decision_tree(partykit) works with type = numeric", {
+  skip_if_not_installed("parsnip")
+  skip_if_not_installed("bonsai")
+  skip_if_not_installed("tidypredict")
+
+  spec <- parsnip::decision_tree("regression", "partykit")
+
+  fit <- parsnip::fit(spec, mpg ~ disp + vs + hp, mtcars)
+
+  orb_obj <- orbital(fit)
+
+  preds <- predict(orb_obj, mtcars)
+  exps <- predict(fit, mtcars)
+
+  expect_named(preds, ".pred")
+  expect_type(preds$.pred, "double")
+
+  exps <- as.data.frame(exps)
+
+  rownames(preds) <- NULL
+  rownames(exps) <- NULL
+
+  expect_equal(
+    preds,
+    exps
+  )
+})
+
 test_that("decision_tree(partykit) works with type = class", {
   skip_if_not_installed("parsnip")
-  skip_if_not_installed("tidypredict")
   skip_if_not_installed("bonsai")
-  library(bonsai)
+  skip_if_not_installed("tidypredict")
 
   mtcars$vs <- factor(mtcars$vs)
 
-  lr_spec <- parsnip::decision_tree("classification", "partykit")
+  spec <- parsnip::decision_tree("classification", "partykit")
 
-  lr_fit <- parsnip::fit(lr_spec, vs ~ disp + mpg + hp, mtcars)
+  fit <- parsnip::fit(spec, vs ~ disp + mpg + hp, mtcars)
 
-  orb_obj <- orbital(lr_fit, type = "class")
+  orb_obj <- orbital(fit, type = "class")
 
   preds <- predict(orb_obj, mtcars)
-  exps <- predict(lr_fit, mtcars)
+  exps <- predict(fit, mtcars)
 
   expect_named(preds, ".pred_class")
   expect_type(preds$.pred_class, "character")
@@ -26,20 +53,19 @@ test_that("decision_tree(partykit) works with type = class", {
 
 test_that("decision_tree(partykit) works with type = prob", {
   skip_if_not_installed("parsnip")
-  skip_if_not_installed("tidypredict")
   skip_if_not_installed("bonsai")
-  library(bonsai)
+  skip_if_not_installed("tidypredict")
 
   mtcars$vs <- factor(mtcars$vs)
 
-  lr_spec <- parsnip::decision_tree("classification", "partykit")
+  spec <- parsnip::decision_tree("classification", "partykit")
 
-  lr_fit <- parsnip::fit(lr_spec, vs ~ disp + mpg + hp, mtcars)
+  fit <- parsnip::fit(spec, vs ~ disp + mpg + hp, mtcars)
 
-  orb_obj <- orbital(lr_fit, type = "prob")
+  orb_obj <- orbital(fit, type = "prob")
 
   preds <- predict(orb_obj, mtcars)
-  exps <- predict(lr_fit, mtcars, type = "prob")
+  exps <- predict(fit, mtcars, type = "prob")
 
   expect_named(preds, c(".pred_0", ".pred_1"))
   expect_type(preds$.pred_0, "double")
@@ -58,22 +84,21 @@ test_that("decision_tree(partykit) works with type = prob", {
 
 test_that("decision_tree(partykit) works with type = c(class, prob)", {
   skip_if_not_installed("parsnip")
-  skip_if_not_installed("tidypredict")
   skip_if_not_installed("bonsai")
-  library(bonsai)
+  skip_if_not_installed("tidypredict")
 
   mtcars$vs <- factor(mtcars$vs)
 
-  lr_spec <- parsnip::decision_tree("classification", "partykit")
+  spec <- parsnip::decision_tree("classification", "partykit")
 
-  lr_fit <- parsnip::fit(lr_spec, vs ~ disp + mpg + hp, mtcars)
+  fit <- parsnip::fit(spec, vs ~ disp + mpg + hp, mtcars)
 
-  orb_obj <- orbital(lr_fit, type = c("class", "prob"))
+  orb_obj <- orbital(fit, type = c("class", "prob"))
 
   preds <- predict(orb_obj, mtcars)
   exps <- dplyr::bind_cols(
-    predict(lr_fit, mtcars, type = c("class")),
-    predict(lr_fit, mtcars, type = c("prob"))
+    predict(fit, mtcars, type = c("class")),
+    predict(fit, mtcars, type = c("prob"))
   )
 
   expect_named(preds, c(".pred_class", ".pred_0", ".pred_1"))
@@ -92,3 +117,19 @@ test_that("decision_tree(partykit) works with type = c(class, prob)", {
     exps
   )
 })
+
+test_that("decision_tree(partykit) works with custom prefix", {
+  skip_if_not_installed("parsnip")
+  skip_if_not_installed("bonsai")
+  skip_if_not_installed("tidypredict")
+
+  spec <- parsnip::decision_tree("regression", "partykit")
+
+  fit <- parsnip::fit(spec, mpg ~ disp + vs + hp, mtcars)
+
+  orb_obj <- orbital(fit, prefix = "my_pred")
+
+  preds <- predict(orb_obj, mtcars)
+
+  expect_named(preds, "my_pred")
+})
